@@ -38,6 +38,14 @@ pub mod server;
 
 use http::HeaderMap;
 
+pub(crate) const HRPC_HEADER: &[u8] = b"application/hrpc";
+
+pub(crate) fn hrpc_header_value() -> HeaderValue {
+    unsafe {
+        http::HeaderValue::from_maybe_shared_unchecked(bytes::Bytes::from_static(HRPC_HEADER))
+    }
+}
+
 #[derive(Debug, Clone)]
 /// A hRPC request.
 pub struct Request<T> {
@@ -55,7 +63,7 @@ impl<T> Request<T> {
             header_map: {
                 #[allow(clippy::mutable_key_type)]
                 let mut map: HeaderMap = HeaderMap::with_capacity(1);
-                map.insert("content-type", "application/hrpc".parse().unwrap());
+                map.insert(http::header::CONTENT_TYPE, hrpc_header_value());
                 map
             },
         }
@@ -90,11 +98,29 @@ impl<T> Request<T> {
         }
     }
 
+    /// Map the contained message.
+    pub fn map<S, Mapper: FnOnce(T) -> S>(self, f: Mapper) -> Request<S> {
+        let Request {
+            message,
+            header_map,
+        } = self;
+
+        Request {
+            message: f(message),
+            header_map,
+        }
+    }
+
     /// Get a reference to the inner message.
-    pub fn get_message(&self) -> &T {
+    pub const fn get_message(&self) -> &T {
         &self.message
     }
 
+    /// Get a reference to the inner header map.
+    pub const fn get_header_map(&self) -> &HeaderMap {
+        &self.header_map
+    }
+
     /// Get a header.
     pub fn get_header(&self, key: &HeaderName) -> Option<&HeaderValue> {
         self.header_map.get(key)
